;; Generated package description from nano-theme.el  -*- no-byte-compile: t -*-
(define-package "nano-theme" "0.3.4" "N Λ N O theme" '((emacs "27.1")) :commit "34a3efc37b329064a320225361ad833c57017485" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("theme" "dark" "light") :url "https://github.com/rougier/nano-theme")
