;;; Directory Local Variables         -*- no-byte-compile: t; -*-
;;; For more information see (info "(emacs) Directory Variables")

((emacs-lisp-mode
  (show-trailing-whitespace . t)
  (indent-tabs-mode . nil)))
